@@ -1,4 +1,4 @@
-﻿module System.Posix.Types.IntWord (module IntWord) where
+module System.Posix.Types.IntWord (module IntWord) where
 
 import Data.Int  as IntWord
-import Data.Word as IntWord
\ No newline at end of file
+import Data.Word as IntWord
